@@ -34,14 +34,14 @@ impl ViewportFactory {
 	/// [`EventLoop`]: winit::event_loop::EventLoop
 	/// [`Window`]: winit::window::Window
 	///
-	pub fn winit<'a>(window: &Window, depth: u32) -> Result<WinitViewport<'a, u32>, ViewportError> {
+	pub fn winit(window: &Window, depth: u32) -> Result<WinitViewport<u32>, ViewportError> {
 		let renderer = render::WinitRenderer::new(window)?;
 		let size = window.inner_size();
 		Ok(Viewport::new(size.width, size.height, depth, renderer))
 	}
 
 	#[cfg(test)]
-	pub fn test<'a>(width: u32, height: u32, depth: u32) -> Viewport<'a, u32, render::mock::MockRenderer> {
+	pub fn test(width: u32, height: u32, depth: u32) -> Viewport<u32, render::mock::MockRenderer> {
 		Viewport::new(width, height, depth, render::mock::MockRenderer::default())
 	}
 
